@@ -1,26 +1,32 @@
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 import subprocess
 
-from python_boilerplate.config import refresh_config, save_config
-from python_boilerplate.core import ConfigManager, FileWriter
-from python_boilerplate.utils import pyname, visit_dir
+from python_boilerplate import io
 from python_boilerplate.commands import subparsers, register
+from python_boilerplate.config import refresh_config
+from python_boilerplate.core import JobConfig, JobWriter
+from python_boilerplate.utils import pyname, visit_dir
+
 license_alias = {
     'gpl': 'gpl3',
 }
 
 
 # Define Config/FileWriter classes
-class InitProject(ConfigManager):
+class InitJobConfig(JobConfig):
     """
     Config options for the `python-boilerplate init` command
     """
 
     def __init__(self, **kwargs):
         self._has_ini_file = not os.path.exists('boilerplate.ini')
-        super().__init__('options', **kwargs)
+        JobConfig.__init__(self, 'options', **kwargs)
 
-    def run(self):
+    def ask_options(self):
         require = self.require
 
         # Asks basic info
@@ -44,28 +50,33 @@ class InitProject(ConfigManager):
         # Save config file
         self.save()
         if self._has_ini_file:
-            editor = input(
+            io.show(
                 '\nYour config file was saved as boilerplate.ini. Leave blank '
-                'to continue or specify a text editor.\n'
-                'Editor: '
-            ).strip()
+                'to continue or specify a text editor.'
+            )
+            editor = io.grab_input('Editor: ').strip()
 
             if editor:
                 subprocess.call([editor, 'boilerplate.ini'])
                 refresh_config()
 
 
-class InitProjectWriter(FileWriter):
+class InitJobWriter(JobWriter):
     """
     File writer for the `python-boilerplate init` command
     """
 
     has_scripts = True
 
+    def __init__(self, config):
+        super().__init__(config, {
+            'requirements': '',
+        })
+
     def get_context(self, **kwargs):
         if isinstance(self.has_scripts, str):
             self.has_scripts = self.has_scripts.lower() == 'yes'
-        return super().get_context(has_scripts=self.has_scripts, **kwargs)
+        return JobWriter.get_context(self, has_scripts=self.has_scripts, **kwargs)
 
     def run(self, ignore=None):
         if ignore is False:
@@ -91,14 +102,11 @@ class InitProjectWriter(FileWriter):
         self.write('setup.pyt', 'setup.py', ignore=ignore)
         self.write('MANIFEST.in', ignore=ignore)
         self.write('requirements.txt', ignore=ignore)
-        self.write('requirements-dev.txt', ignore=ignore)
 
         # Package structure
         basedir = 'src/%s' % self.pyname
         self.write('package/init.pyt',
                    '%s/__init__.py' % basedir, ignore=True)
-        self.write('package/meta.pyt',
-                   '%s/__meta__.py' % basedir, ignore=ignore)
         if self.has_scripts:
             self.write('package/main.pyt',
                        '%s/__main__.py' % basedir, ignore=ignore)
@@ -124,11 +132,13 @@ class InitProjectWriter(FileWriter):
                 if not os.path.exists(folder):
                     os.mkdir(folder)
 
+
 # Setup the "init" subparser
 cmd = subparsers.add_parser('init', help='create a new project')
-cmd.add_argument('project', nargs='?', help='Your Python Boilerplate project\' name')
+cmd.add_argument('project', nargs='?',
+                 help='Your Python Boilerplate project\' name')
 cmd.add_argument('--author', '-a', help='author\'s name')
 cmd.add_argument('--email', '-e', help='author\'s e-mail')
 cmd.add_argument('--license', '-l', help='project\'s license')
 cmd.add_argument('--version', '-v', help='project\'s version')
-register(cmd, InitProject, InitProjectWriter)
+register(cmd, InitJobConfig, InitJobWriter)
